#
# Configure paths and flags for the AirRAC library.
# Denis Arnaud <denis_arnaud at users dot sourceforge dot net>, July 2008
#
# Note: the AIRRAC library depends upon BOOST to build.
# Your configure.ac must therefore define appropriately the BOOST
# variables (i.e., BOOST_CFLAGS, BOOST_LIBS, BOOST_DATE_TIME_LIB).
#
# Variables set by this macro:
#  * AIRRAC_VERSION
#  * AIRRAC_CFLAGS
#  * AIRRAC_LIBS
#  * AIRRAC_SAMPLE_DIR
#

AC_DEFUN([AM_PATH_AIRRAC],
[
AC_LANG_SAVE
AC_LANG([C++])

##
AC_ARG_WITH(airrac,
	[ --with-airrac=PFX Prefix where AirRAC is installed (optional) ],
	    airrac_dir="$withval",
	    airrac_dir="")

  if test "x${AIRRAC_CONFIG+set}" != xset ; then
     if test "x$airrac_dir" != x ; then
         AIRRAC_CONFIG="$airrac_dir/bin/airrac-config"
     fi
  fi

  AC_PATH_PROG(AIRRAC_CONFIG, airrac-config, no)

  ## Check whether Boost flags and libraries are defined
  # General Boost compilation flags
  AC_MSG_CHECKING(for BOOST_CFLAGS environment variable)
  if test x"${BOOST_CFLAGS}" = x; then
	AC_MSG_RESULT([Warning: AirRAC needs Boost, and the BOOST_CFLAGS environment variable does not appear to be set. It may not be a problem, though, if your Unix distribution is standard, that is, if Boost is installed in /usr. Otherwise, the AirRAC will fail to compile.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_CFLAGS})])
  fi

  # Boost Date-Time library
  AC_MSG_CHECKING(for BOOST_DATE_TIME_LIB environment variable)
  if test x"${BOOST_DATE_TIME_LIB}" = x; then
	AC_MSG_RESULT([Warning: AirRAC needs the Boost Date-Time library, and the BOOST_DATE_TIME_LIB environment variable does not appears to be set. The AirRAC may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_DATE_TIME_LIB})])
  fi

  # Boost Program Options library
  AC_MSG_CHECKING(for BOOST_PROGRAM_OPTIONS_LIB environment variable)
  if test x"${BOOST_PROGRAM_OPTIONS_LIB}" = x; then
	AC_MSG_RESULT([Warning: AirRAC needs the Boost Program Options library, and the BOOST_PROGRAM_OPTIONS_LIB environment variable does not appears to be set. The AirRAC may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_PROGRAM_OPTIONS_LIB})])
  fi

  # Boost File System library
  AC_MSG_CHECKING(for BOOST_FILESYSTEM_LIB environment variable)
  if test x"${BOOST_FILESYSTEM_LIB}" = x; then
	AC_MSG_RESULT([Warning: AirRAC needs the Boost Date-Time library, and the BOOST_FILESYSTEM_LIB environment variable does not appears to be set. The AirRAC may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_FILESYSTEM_LIB})])
  fi

  ## AirRAC version
  min_airrac_version=ifelse([$1], ,0.1.0,$1)
  AC_MSG_CHECKING(for AirRAC - version >= $min_airrac_version)
  no_airrac=""
  if test "${AIRRAC_CONFIG}" = "no" ; then
     no_airrac=yes
     AC_MSG_RESULT([no])
  else
     AIRRAC_VERSION=`${AIRRAC_CONFIG} --version`
     AIRRAC_CFLAGS=`${AIRRAC_CONFIG} --cflags`
     AIRRAC_CFLAGS="${BOOST_CFLAGS} ${AIRRAC_CFLAGS}"
     AIRRAC_LIBS=`${AIRRAC_CONFIG} --libs`
     AIRRAC_LIBS="${BOOST_LIBS} ${BOOST_DATE_TIME_LIB} ${AIRRAC_LIBS}"
     AIRRAC_SAMPLE_DIR=`${AIRRAC_CONFIG} --sampledir`

     AC_SUBST([AIRRAC_VERSION])
     AC_SUBST([AIRRAC_CFLAGS])
     AC_SUBST([AIRRAC_LIBS])
     AC_SUBST([AIRRAC_SAMPLE_DIR])

    airrac_major_version=`echo ${AIRRAC_VERSION} | sed 's/^\([[0-9]]*\).*/\1/'`
    if test "x${airrac_major_version}" = "x" ; then
       airrac_major_version=0
    fi

    airrac_minor_version=`echo ${AIRRAC_VERSION} | \
						sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\2/'`
    if test "x${airrac_minor_version}" = "x" ; then
       airrac_minor_version=0
    fi

    airrac_micro_version=`echo ${AIRRAC_VERSION} | \
          sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\3/'`
    if test "x${airrac_micro_version}" = "x" ; then
       airrac_micro_version=0
    fi

    ## Simple test of compilation and link
    SAVED_CPPFLAGS="${CPPFLAGS}"
    SAVED_LDFLAGS="${LDFLAGS}"
    CPPFLAGS="${CPPFLAGS} ${BOOST_CFLAGS} ${AIRRAC_CFLAGS}"
    LDFLAGS="${LDFLAGS} ${AIRRAC_LIBS}"


    AC_COMPILE_IFELSE(
		[AC_LANG_PROGRAM([[#include <airrac/AIRRAC_Service.hpp>
				]],
				[[int i=0;]]
		)]
		,

    	[AC_MSG_RESULT([yes (${AIRRAC_VERSION})])],

	[AC_MSG_ERROR([We could not compile a simple AirRAC example. See config.log.])]
    )

    CPPFLAGS="${SAVED_CPPFLAGS}"
    LDFLAGS="${SAVED_LDFLAGS}"

  fi

AC_LANG_RESTORE
])
